/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "RemoteLegacyCDMProxy.h"

#include "ArgumentCoders.h"
#include "Decoder.h"
#include "HandleMessage.h"
#include "RemoteLegacyCDMProxyMessages.h"
#include "RemoteLegacyCDMSessionIdentifier.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/MediaPlayerIdentifier.h>
#include <wtf/Optional.h>
#include <wtf/text/WTFString.h>

namespace Messages {

namespace RemoteLegacyCDMProxy {

void SupportsMIMEType::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool supports)
{
    *encoder << supports;
    connection.sendSyncReply(WTFMove(encoder));
}

void CreateSession::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const WebKit::RemoteLegacyCDMSessionIdentifier& identifier)
{
    *encoder << identifier;
    connection.sendSyncReply(WTFMove(encoder));
}

} // namespace RemoteLegacyCDMProxy

} // namespace Messages

namespace WebKit {

void RemoteLegacyCDMProxy::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::RemoteLegacyCDMProxy::SetPlayerId::name()) {
        IPC::handleMessage<Messages::RemoteLegacyCDMProxy::SetPlayerId>(decoder, this, &RemoteLegacyCDMProxy::setPlayerId);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

void RemoteLegacyCDMProxy::didReceiveSyncMessage(IPC::Connection& connection, IPC::Decoder& decoder, std::unique_ptr<IPC::Encoder>& replyEncoder)
{
    if (decoder.messageName() == Messages::RemoteLegacyCDMProxy::SupportsMIMEType::name()) {
        IPC::handleMessageSynchronous<Messages::RemoteLegacyCDMProxy::SupportsMIMEType>(connection, decoder, replyEncoder, this, &RemoteLegacyCDMProxy::supportsMIMEType);
        return;
    }
    if (decoder.messageName() == Messages::RemoteLegacyCDMProxy::CreateSession::name()) {
        IPC::handleMessageSynchronous<Messages::RemoteLegacyCDMProxy::CreateSession>(connection, decoder, replyEncoder, this, &RemoteLegacyCDMProxy::createSession);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    UNUSED_PARAM(replyEncoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
