/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
#include "RemoteLegacyCDMSessionProxy.h"

#include "ArgumentCoders.h"
#include "Decoder.h"
#include "HandleMessage.h"
#include "RemoteLegacyCDMSessionProxyMessages.h"
#include "SharedBufferCopy.h"
#include <wtf/Optional.h>
#include <wtf/text/WTFString.h>

namespace Messages {

namespace RemoteLegacyCDMSessionProxy {

void GenerateKeyRequest::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Optional<IPC::SharedBufferCopy>& nextMessage, const String& destinationURL, const unsigned short& errorCode, uint32_t systemCode)
{
    *encoder << nextMessage;
    *encoder << destinationURL;
    *encoder << errorCode;
    *encoder << systemCode;
    connection.sendSyncReply(WTFMove(encoder));
}

void Update::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool succeeded, const Optional<IPC::SharedBufferCopy>& nextMessage, const unsigned short& errorCode, uint32_t systemCode)
{
    *encoder << succeeded;
    *encoder << nextMessage;
    *encoder << errorCode;
    *encoder << systemCode;
    connection.sendSyncReply(WTFMove(encoder));
}

void CachedKeyForKeyID::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Optional<IPC::SharedBufferCopy>& key)
{
    *encoder << key;
    connection.sendSyncReply(WTFMove(encoder));
}

} // namespace RemoteLegacyCDMSessionProxy

} // namespace Messages

namespace WebKit {

void RemoteLegacyCDMSessionProxy::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::RemoteLegacyCDMSessionProxy::ReleaseKeys::name()) {
        IPC::handleMessage<Messages::RemoteLegacyCDMSessionProxy::ReleaseKeys>(decoder, this, &RemoteLegacyCDMSessionProxy::releaseKeys);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

void RemoteLegacyCDMSessionProxy::didReceiveSyncMessage(IPC::Connection& connection, IPC::Decoder& decoder, std::unique_ptr<IPC::Encoder>& replyEncoder)
{
    if (decoder.messageName() == Messages::RemoteLegacyCDMSessionProxy::GenerateKeyRequest::name()) {
        IPC::handleMessageSynchronous<Messages::RemoteLegacyCDMSessionProxy::GenerateKeyRequest>(connection, decoder, replyEncoder, this, &RemoteLegacyCDMSessionProxy::generateKeyRequest);
        return;
    }
    if (decoder.messageName() == Messages::RemoteLegacyCDMSessionProxy::Update::name()) {
        IPC::handleMessageSynchronous<Messages::RemoteLegacyCDMSessionProxy::Update>(connection, decoder, replyEncoder, this, &RemoteLegacyCDMSessionProxy::update);
        return;
    }
    if (decoder.messageName() == Messages::RemoteLegacyCDMSessionProxy::CachedKeyForKeyID::name()) {
        IPC::handleMessageSynchronous<Messages::RemoteLegacyCDMSessionProxy::CachedKeyForKeyID>(connection, decoder, replyEncoder, this, &RemoteLegacyCDMSessionProxy::cachedKeyForKeyID);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    UNUSED_PARAM(replyEncoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS) && ENABLE(LEGACY_ENCRYPTED_MEDIA)
