/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "SourceBufferPrivateRemote.h"

#include "Decoder.h"
#include "HandleMessage.h"
#include "InitializationSegmentInfo.h"
#include "SourceBufferPrivateRemoteMessages.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/PlatformTimeRanges.h>
#include <WebCore/SourceBufferPrivateClient.h>
#include <wtf/MediaTime.h>

namespace Messages {

namespace SourceBufferPrivateRemote {

void SourceBufferPrivateDidReceiveInitializationSegment::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SourceBufferPrivateDidReceiveInitializationSegment::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SourceBufferPrivateDidReceiveInitializationSegment::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

} // namespace SourceBufferPrivateRemote

} // namespace Messages

namespace WebKit {

void SourceBufferPrivateRemote::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveInitializationSegment::name()) {
        IPC::handleMessageAsync<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveInitializationSegment>(connection, decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateDidReceiveInitializationSegment);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateStreamEndedWithDecodeError::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateStreamEndedWithDecodeError>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateStreamEndedWithDecodeError);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateAppendError::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateAppendError>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateAppendError);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateAppendComplete::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateAppendComplete>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateAppendComplete);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateHighestPresentationTimestampChanged::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateHighestPresentationTimestampChanged>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateHighestPresentationTimestampChanged);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateDurationChanged::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDurationChanged>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateDurationChanged);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidParseSample::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidParseSample>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateDidParseSample);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidDropSample::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidDropSample>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateDidDropSample);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateBufferedDirtyChanged::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateBufferedDirtyChanged>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateBufferedDirtyChanged);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateBufferedRangesChanged::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateBufferedRangesChanged>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateBufferedRangesChanged);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveRenderingError::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateDidReceiveRenderingError>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateDidReceiveRenderingError);
        return;
    }
    if (decoder.messageName() == Messages::SourceBufferPrivateRemote::SourceBufferPrivateReportExtraMemoryCost::name()) {
        IPC::handleMessage<Messages::SourceBufferPrivateRemote::SourceBufferPrivateReportExtraMemoryCost>(decoder, this, &SourceBufferPrivateRemote::sourceBufferPrivateReportExtraMemoryCost);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
